from .page import Page

class Pagelist:
    def __init__(self, pagelist):
        self.data = []

    